
= net/pop.rb version 1.1.33

written by Minero Aoki <aamine@dp.u-netsurf.ne.jp>

This program is free software.
You can distribute/modify this program under
the terms of the Ruby Distribute License.

Japanese version of this document is in "net" full package.
You can get it from RAA
(Ruby Application Archive: http://www.ruby-lang.org/en/raa.html).


== Net::POP3

=== Super Class

Net::Protocol

=== Class Methods

: new( address = 'localhost', port = 110 )
  creates a new Net::POP3 object.
  This method does not open TCP connection yet.

: start( address = 'localhost', port = 110, account, password )
: start( address = 'localhost', port = 110, account, password ) {|pop| .... }
  equals to Net::POP3.new( address, port ).start( account, password )

    # typical usage
    Net::POP3.start( addr, port, acnt, pass ) do |pop|
      pop.each_mail do |m|
        any_file.write m.pop
        m.delete
      end
    end

: foreach( address = 'localhost', port = 110, account, password ) {|mail| .... }
  starts protocol and iterate for each POPMail object.
  This method equals to

    Net::POP3.start( address, port, account, password ) do |pop|
      pop.each do |m|
        yield m
      end
    end

  .

    # typical usage
    Net::POP3.foreach( addr, nil, acnt, pass ) do |m|
      m.pop file
      m.delete
    end

: delete_all( address = 'localhost', port = 110, account, password )
: delete_all( address = 'localhost', port = 110, account, password ) {|mail| .... }
  starts POP3 session and delete all mails.
  If block is given, iterates for each POPMail object before delete.

    # typical usage
    Net::POP3.delete_all( addr, nil, acnt, pass ) do |m|
      m.pop file
    end
  
=== Methods

: start( account, password )
: start( account, password ) {|pop| .... }
  starts POP3 session.

  When called with block, gives a POP3 object to block and
  closes the session after block call finish.

: mails
  an array of ((URL:#POPMail)).
  This array is renewed when session started.

: each_mail {|popmail| .... }
: each {|popmail| .... }
  is equals to "pop3.mails.each"

: delete_all
: delete_all {|popmail| .... }
  deletes all mails.
  If called with block, gives mails to the block before deleting.

    # example 1
    # pop and delete all mails
    n = 1
    pop.delete_all do |m|
      File.open("inbox/#{n}") {|f| f.write m.pop }
      n += 1
    end

    # example 2
    # clear all mails on server
    Net::POP3.start( addr, port, acc, pass ) do |pop|
      pop.delete_all
    end

: reset
  reset the session. All "deleted mark" are removed.


== Net::APOP

This class defines no new methods.
Only difference from POP3 is using APOP authentification.

=== Super Class

Net::POP3


== Net::POPMail

A class of mail which exists on POP server.

=== Super Class

Object


=== Methods

: pop( dest = '' )
  This method fetches a mail and write to 'dest' using '<<' method.

    # usage example

    mailarr = []
    POP3.start( 'localhost', 110 ) do |pop|
      pop.each_mail do |popm|
        mailarr.push popm.pop   # all() returns 'dest' (this time, string)
        # or, you can also
        # popm.pop( $stdout )   # write mail to stdout

        # maybe you also want to delete mail after popping
        popm.delete
      end
    end

: pop {|str| .... }
  If pop() is called with block, it gives the block part strings of a mail.

    # usage example

    POP3.start( 'localhost', 110 ) do |pop3|
      pop3.each_mail do |m|
        m.pop do |str|
          # do anything
        end
      end
    end

: header
  This method fetches only mail header.

: top( lines )
  This method fetches mail header and 'lines' lines body.

: delete
: delete!
  This method deletes mail.

: size
  size of mail(bytes)

: deleted?
  true if mail was deleted

